@@ -29,7 +29,7 @@
 #   define NODE_EXTERN __declspec(dllimport)
 # endif
 #else
-# define NODE_EXTERN /* nothing */
+# define NODE_EXTERN __attribute__((visibility("default")))
 #endif
 
 #ifdef BUILDING_NODE_EXTENSION
@@ -100,15 +100,16 @@
 // Forward-declare libuv loop
 struct uv_loop_s;
 
-// Forward-declare TracingController, used by CreatePlatform.
-namespace v8 {
-class TracingController;
-}
-
 // Forward-declare these functions now to stop MSVS from becoming
 // terminally confused when it's done in node_internals.h
 namespace node {
 
+namespace tracing {
+
+class TracingController;
+
+}
+
 NODE_EXTERN v8::Local<v8::Value> ErrnoException(v8::Isolate* isolate,
                                                 int errorno,
                                                 const char* syscall = nullptr,
@@ -275,7 +276,7 @@ NODE_EXTERN MultiIsolatePlatform* GetMainThreadMultiIsolatePlatform();
 
 NODE_EXTERN MultiIsolatePlatform* CreatePlatform(
     int thread_pool_size,
-    v8::TracingController* tracing_controller);
+    node::tracing::TracingController* tracing_controller);
 MultiIsolatePlatform* InitializeV8Platform(int thread_pool_size);
 NODE_EXTERN void FreePlatform(MultiIsolatePlatform* platform);
 
@@ -368,7 +369,7 @@ inline void NODE_SET_METHOD(v8::Local<v8::Object> recv,
   v8::Local<v8::String> fn_name = v8::String::NewFromUtf8(isolate, name,
       v8::NewStringType::kInternalized).ToLocalChecked();
   fn->SetName(fn_name);
-  recv->Set(fn_name, fn);
+  recv->Set(context, fn_name, fn).FromJust();
 }
 #define NODE_SET_METHOD node::NODE_SET_METHOD
 
@@ -561,13 +562,15 @@ extern "C" NODE_EXTERN void node_module_register(void* mod);
 /* Called after the event loop exits but before the VM is disposed.
  * Callbacks are run in reverse order of registration, i.e. newest first.
  */
-NODE_EXTERN void AtExit(void (*cb)(void* arg), void* arg = 0);
+NODE_EXTERN void AtExit(void (*cb)(void* arg), void* arg = nullptr);
 
 /* Registers a callback with the passed-in Environment instance. The callback
  * is called after the event loop exits, but before the VM is disposed.
  * Callbacks are run in reverse order of registration, i.e. newest first.
  */
-NODE_EXTERN void AtExit(Environment* env, void (*cb)(void* arg), void* arg = 0);
+NODE_EXTERN void AtExit(Environment* env,
+                        void (*cb)(void* arg),
+                        void* arg = nullptr);
 
 typedef void (*promise_hook_func) (v8::PromiseHookType type,
                                    v8::Local<v8::Promise> promise,
@@ -652,14 +655,14 @@ class NODE_EXTERN CallbackScope {
                 async_context asyncContext);
   ~CallbackScope();
 
- private:
-  InternalCallbackScope* private_;
-  v8::TryCatch try_catch_;
-
   void operator=(const CallbackScope&) = delete;
   void operator=(CallbackScope&&) = delete;
   CallbackScope(const CallbackScope&) = delete;
   CallbackScope(CallbackScope&&) = delete;
+
+ private:
+  InternalCallbackScope* private_;
+  v8::TryCatch try_catch_;
 };
 
 /* An API specific to emit before/after callbacks is unnecessary because
@@ -709,16 +712,6 @@ class AsyncResource {
                                    trigger_async_id);
   }
 
-  AsyncResource(v8::Isolate* isolate,
-                v8::Local<v8::Object> resource,
-                v8::Local<v8::String> name,
-                async_id trigger_async_id = -1)
-      : isolate_(isolate),
-        resource_(isolate, resource) {
-    async_context_ = EmitAsyncInit(isolate, resource, name,
-                                   trigger_async_id);
-  }
-
   virtual ~AsyncResource() {
     EmitAsyncDestroy(isolate_, async_context_);
     resource_.Reset();
